@@ -92,8 +92,8 @@ def write_to_file(model, read_length, mean_f, mean_r, hist_f, hist_r,
             insert_size=i_size,
             mean_count_forward=mean_f,
             mean_count_reverse=mean_r,
-            quality_hist_forward=hist_f,
-            quality_hist_reverse=hist_r,
+            quality_hist_forward=np.array(hist_f, dtype=object),
+            quality_hist_reverse=np.array(hist_r, dtype=object),
             subst_choices_forward=sub_f,
             subst_choices_reverse=sub_r,
             ins_forward=ins_f,
