@@ -6,8 +6,11 @@ from iss import util
 import sys
 import random
 import logging
+import _pickle
 import numpy as np
 
+from Bio.Seq import Seq, MutableSeq
+
 
 class ErrorModel(object):
     """Main ErrorModel Class
@@ -35,7 +38,7 @@ class ErrorModel(object):
         try:
             error_profile = np.load(npz_path, allow_pickle=True)
             assert error_profile['model'] == model
-        except (OSError, IOError) as e:
+        except (OSError, IOError, EOFError, _pickle.UnpicklingError) as e:
             self.logger.error('Failed to read ErrorModel file: %s' % e)
             sys.exit(1)
         except AssertionError as e:
@@ -87,7 +90,7 @@ class ErrorModel(object):
         elif orientation == 'reverse':
             nucl_choices = self.subst_choices_rev
 
-        mutable_seq = record.seq.tomutable()
+        mutable_seq = MutableSeq(record.seq)
         quality_list = record.letter_annotations["phred_quality"]
         position = 0
         for nucl, qual in zip(mutable_seq, quality_list):
@@ -97,7 +100,7 @@ class ErrorModel(object):
                     nucl_choices[position][nucl.upper()][0],
                     p=nucl_choices[position][nucl.upper()][1]))
             position += 1
-        return mutable_seq.toseq()
+        return Seq(mutable_seq)
 
     def adjust_seq_length(self, mut_seq, orientation, full_sequence, bounds):
         """Truncate or Extend reads to make them fit the read length
@@ -120,11 +123,11 @@ class ErrorModel(object):
         """
         read_start, read_end = bounds
         if len(mut_seq) == self.read_length:
-            return mut_seq.toseq()
+            return Seq(mut_seq)
         elif len(mut_seq) > self.read_length:
             while len(mut_seq) > self.read_length:
                 mut_seq.pop()
-            return mut_seq.toseq()
+            return Seq(mut_seq)
         else:  # len smaller
             to_add = self.read_length - len(mut_seq)
             if orientation == 'forward':
@@ -142,7 +145,7 @@ class ErrorModel(object):
                         nucl_to_add = util.rev_comp(
                             full_sequence[read_end + i])
                     mut_seq.append(nucl_to_add)
-            return mut_seq.toseq()
+            return Seq(mut_seq)
 
     def introduce_indels(self, record, orientation, full_seq, bounds):
         """Introduce insertions or deletions in a sequence
@@ -171,7 +174,7 @@ class ErrorModel(object):
             insertions = self.ins_rev
             deletions = self.del_rev
 
-        mutable_seq = record.seq.tomutable()
+        mutable_seq = MutableSeq(record.seq)
         position = 0
         for nucl in range(self.read_length - 1):
             try:
