@@ -1,20 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import pytest
+
 from iss import bam
 
-from nose.tools import raises
-
 import os
-import sys
 
 
-@raises(SystemExit)
 def test_read_fail():
-    bam_file = 'data/empty_file'
-    bam_reader = bam.read_bam(bam_file)
-    for read in bam_reader:
-        print(read)
+    with pytest.raises(SystemExit):
+        bam_file = 'data/empty_file'
+        bam_reader = bam.read_bam(bam_file)
+        for read in bam_reader:
+            print(read)
 
 
 def test_to_model():
